/*
 * inttypes.h
 */


#ifndef inttypes_h
#define inttypes_h


#include<sys/inttypes.h>


#endif
